@@ -1,7 +1,7 @@
 package Perinci::Sub::To::FuncBase;
 
-our $DATE = '2015-09-04'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2015-09-23'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -16,6 +16,8 @@ with 'Perinci::To::Doc::Role::Section';
 
 has meta => (is=>'rw');
 has name => (is=>'rw');
+has url  => (is=>'rw');
+has _pa => (is=>'rw');
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -30,6 +32,10 @@ sub BUILD {
         'examples',
         'links',
     ];
+    $self->{_pa} = do {
+        require Perinci::Access;
+        Perinci::Access->new;
+    };
 }
 
 sub before_gen_doc {
@@ -191,7 +197,7 @@ Perinci::Sub::To::FuncBase - Base class for Perinci::Sub::To::* function documen
 
 =head1 VERSION
 
-This document describes version 0.63 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2015-09-04.
+This document describes version 0.64 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2015-09-23.
 
 =for Pod::Coverage .+
 
