@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2015-09-04'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2015-09-23'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -77,7 +77,7 @@ sub after_gen_doc {
                 if ($args_as =~ /hash/) {
                     require Perinci::Sub::GetArgs::Argv;
                     my $gares = Perinci::Sub::GetArgs::Argv::get_args_from_argv(
-                        argv => $eg->{argv},
+                        argv => [@{ $eg->{argv} }],
                         meta => $meta,
                         per_arg_json => 1,
                         per_arg_yaml => 1,
@@ -109,7 +109,25 @@ sub after_gen_doc {
             my $resdump;
             if (exists $eg->{result}) {
                 $resdump = Data::Dump::dump($eg->{result});
+            } else {
+              GET_RESULT_BY_CALLING_FUNCTION:
+                {
+                    # XXX since we retrieve the result by calling through Riap,
+                    # the result will be json-cleaned.
+                    my %extra;
+                    if ($eg->{argv}) {
+                        $extra{argv} = $eg->{argv};
+                    } elsif($eg->{args}) {
+                        $extra{args} = $eg->{args};
+                    } else {
+                        $log->debugf("Example does not provide args/argv, skipped trying to get result from calling function");
+                        last GET_RESULT_BY_CALLING_FUNCTION;
+                    }
+                    my $res = $self->{_pa}->request(call => $self->{url}, \%extra);
+                    $resdump = Data::Dump::dump($res);
+                }
             }
+
             my $status = $eg->{status} // 200;
             my $comment;
             my @expl;
@@ -124,7 +142,10 @@ sub after_gen_doc {
                     $comment = "ERROR $status";
                 }
             } else {
-                push @expl, "Result: C<< $resdump >>." if defined($resdump);
+                if (defined $resdump) {
+                    $resdump =~ s/^/ /gm;
+                    push @expl, "Result:\n\n$resdump";
+                }
             }
             push @expl, ($eg->{summary} . ($eg->{summary} =~ /\.$/ ? "" : "."))
                 if $eg->{summary};
@@ -306,7 +327,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.63 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-04.
+This document describes version 0.64 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-23.
 
 =head1 SYNOPSIS
 
