@@ -1,7 +1,7 @@
 package Perinci::To::POD;
 
-our $DATE = '2015-09-04'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2015-09-23'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -87,7 +87,7 @@ sub gen_doc_section_description {
 
 sub _gen_func_doc {
     my $self = shift;
-    my $o = Perinci::Sub::To::POD->new(@_);
+    my $o = Perinci::Sub::To::POD->new(_pa => $self->{_pa}, @_);
     $o->gen_doc;
     $o->doc_lines;
 }
@@ -153,7 +153,7 @@ Perinci::To::POD - Generate POD documentation for a package from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.63 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-04.
+This document describes version 0.64 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-23.
 
 =head1 SYNOPSIS
 
