@@ -1,7 +1,7 @@
 package Perinci::To::PackageBase;
 
-our $DATE = '2015-09-04'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2015-09-23'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010;
 use Data::Dump::OneLine qw(dump1);
@@ -13,7 +13,9 @@ with 'Perinci::To::Doc::Role::Section';
 
 has name => (is=>'rw');
 has meta => (is=>'rw');
+has url  => (is=>'rw');
 has child_metas => (is=>'rw');
+has _pa => (is=>'rw');
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -27,6 +29,10 @@ sub BUILD {
         'functions',
         'links',
     ];
+    $self->{_pa} //= do {
+        require Perinci::Access;
+        Perinci::Access->new;
+    };
 }
 
 sub before_gen_doc {
@@ -98,7 +104,7 @@ sub gen_doc_section_functions {
         my $meta = $cmetas->{$furi};
         next if $meta->{'x.no_index'};
         $dres->{functions}{$furi} =
-            $self->_gen_func_doc(name=>$fname, meta=>$meta);
+            $self->_gen_func_doc(name=>$fname, meta=>$meta, url=>"$self->{url}$furi");
     }
 }
 
@@ -120,7 +126,7 @@ Perinci::To::PackageBase - Base class for Perinci::To::* package documentation g
 
 =head1 VERSION
 
-This document describes version 0.63 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2015-09-04.
+This document describes version 0.64 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2015-09-23.
 
 =for Pod::Coverage .+
 
